##  Using the Inventory AI Prompts
To use the inventory AI prompts, do the following:
  1. Click Start AI prompt in the inventory to open the Inventory AI Prompt page.
  2. Enter your prompt in the prompt field, or select predefined prompts from the drop-down menu. Predefined prompts also automatically apply filters as required.
  3. Click on the Run Request button (play icon) next to the fact sheets for which you want to execute the request. You can also select multiple fact sheets and run the request at once for selected fact sheets.
  4. To ensure accuracy, it's recommended to review AI-generated content before saving it to the fact sheet. Therefore, you need to confirm each response individually by clicking the Save icon represented by the check mark.
  5. If the response is not satisfactory, you can regenerate it by clicking the Run Request button (play icon).


![Using Inventory AI Prompt](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275536db7a441014bbd592d8b8aa34c0_LowRes.gif)
Using Inventory AI Prompt
